# Documentation for the Timeline

From the `VCalendar` it is very easy to create a Timeline object. This will show you all the components you have in a specific time frame.

::: ical_library.timeline.Timeline
